Module sparkle_cache::backend
source · Expand description
The trait to define how to get and set data in the backend
This is for adding support for a backend
Traits
Provides methods to add, replace or delete data in the cache
The trait to define how to get and set data in the backend
This is for adding support for a backend