pub enum Error<E: Send> {
    Backend(E),
    CurrentUserMissing,
    MemberRoleMissing {
        user_id: Id<UserMarker>,
        role_id: Id<RoleMarker>,
    },
    MemberBadTimeoutTimestamp(Box<CachedMember>),
    PermissionsChannelMissing(Id<ChannelMarker>),
    PermissionsGuildMissing(Id<GuildMarker>),
    PermissionsMemberMissing {
        user_id: Id<UserMarker>,
        guild_id: Id<GuildMarker>,
    },
    PermissionsGuildEveryoneRoleMissing(Id<GuildMarker>),
    PermissionsChannelNotInGuild(Box<CachedChannel>),
}
The errors the cache might return

Variants

Backend(E)

An error was returned by the backend

CurrentUserMissing

The current user isn’t in the cache

MemberRoleMissing

Fields

user_id: Id<UserMarker>

The member’s user ID

role_id: Id<RoleMarker>

The missing role’s ID

One of the roles of the member to cache isn’t in the cache

MemberBadTimeoutTimestamp(Box<CachedMember>)

The timestamp the member’s communication is disabled until isn’t valid

PermissionsChannelMissing(Id<ChannelMarker>)

The channel to calculate permissions for isn’t in the cache

PermissionsGuildMissing(Id<GuildMarker>)

The guild to calculate permissions for isn’t in the cache

PermissionsMemberMissing

Fields

user_id: Id<UserMarker>

The member’s user ID

guild_id: Id<GuildMarker>

The guild’s ID

The member to calculate permissions for isn’t in the cache

PermissionsGuildEveryoneRoleMissing(Id<GuildMarker>)

The everyone role in the guild to calculate permissions for isn’t in the cache

PermissionsChannelNotInGuild(Box<CachedChannel>)

The given channel to calculate permissions for doesn’t have a guild ID