Struct sparkle_cache::model::CachedAttachment
source · pub struct CachedAttachment {
pub message_id: Id<MessageMarker>,
pub content_type: Option<String>,
pub ephemeral: bool,
pub filename: String,
pub description: Option<String>,
pub height: Option<u64>,
pub id: Id<AttachmentMarker>,
pub proxy_url: String,
pub size: u64,
pub url: String,
pub width: Option<u64>,
}Expand description
A cached attachment
It’s the same as twilight_model::channel::Attachment except:
message_idfield is added, making it possible to return a message’s attachments
Fields
message_id: Id<MessageMarker>content_type: Option<String>ephemeral: boolfilename: Stringdescription: Option<String>height: Option<u64>id: Id<AttachmentMarker>proxy_url: Stringsize: u64url: Stringwidth: Option<u64>Implementations
sourceimpl CachedAttachment
impl CachedAttachment
sourcepub fn from_attachment(
attachment: Attachment,
message_id: Id<MessageMarker>
) -> Self
pub fn from_attachment(
attachment: Attachment,
message_id: Id<MessageMarker>
) -> Self
Create a cached attachment from a given attachment and message ID