pub struct CachedEmbedField {
    pub embed_id: Id<GenericMarker>,
    pub inline: bool,
    pub name: String,
    pub value: String,
}
A cached embed field

It’s the same as [twilight_model::channel::embed::EmbedField] except:

  • embed_id field is added, making it possible to return an embed’s fields

Fields

embed_id: Id<GenericMarker>inline: boolname: Stringvalue: String

Implementations

Create a cached embed field from a given embed field and embed ID