Struct sparkle_cache::model::CachedEmoji
source · pub struct CachedEmoji {
pub guild_id: Id<GuildMarker>,
pub animated: bool,
pub available: bool,
pub id: Id<EmojiMarker>,
pub managed: bool,
pub name: String,
pub require_colons: bool,
pub user: Option<Id<UserMarker>>,
}Expand description
A cached emoji
It’s the same as twilight_model::guild::Emoji
except:
-
guild_idfield is added, making it possible to return a guild’s emojis -
userfield is changed to a user ID, as users are cached separately -
rolesfield is removed, as caching it is likely unnecessary, if you need this field, please create an issue
Fields
guild_id: Id<GuildMarker>animated: boolavailable: boolid: Id<EmojiMarker>managed: boolname: Stringrequire_colons: booluser: Option<Id<UserMarker>>Implementations
sourceimpl CachedEmoji
impl CachedEmoji
sourcepub fn from_emoji(emoji: &Emoji, guild_id: Id<GuildMarker>) -> Self
pub fn from_emoji(emoji: &Emoji, guild_id: Id<GuildMarker>) -> Self
Create a cached emoji from a given emoji and guild ID