Struct sparkle_cache::model::CachedMessage
source · pub struct CachedMessage {Show 27 fields
pub activity_type: Option<MessageActivityType>,
pub activity_party_id: Option<String>,
pub application_cover_image: Option<ImageHash>,
pub application_description: Option<String>,
pub application_icon: Option<ImageHash>,
pub application_id: Option<Id<ApplicationMarker>>,
pub application_name: Option<String>,
pub interaction_application_id: Option<Id<ApplicationMarker>>,
pub author: Id<UserMarker>,
pub channel_id: Id<ChannelMarker>,
pub content: String,
pub edited_timestamp: Option<Timestamp>,
pub flags: Option<MessageFlags>,
pub guild_id: Option<Id<GuildMarker>>,
pub id: Id<MessageMarker>,
pub kind: MessageType,
pub mention_everyone: bool,
pub pinned: bool,
pub reference_channel_id: Option<Id<ChannelMarker>>,
pub reference_guild_id: Option<Id<GuildMarker>>,
pub reference_message_id: Option<Id<MessageMarker>>,
pub reference_fail_if_not_exists: Option<bool>,
pub referenced_message: Option<Id<MessageMarker>>,
pub timestamp: Timestamp,
pub thread: Option<Id<ChannelMarker>>,
pub tts: bool,
pub webhook_id: Option<Id<WebhookMarker>>,
}Expand description
A cached message
It’s the same as twilight_model::channel::message::Message except:
-
activityandreferencefields are flattened, making this struct easier to cache -
author,referenced_messageandthreadfields are changed to their IDs, since they’re cached separately -
components,interaction,mention_channels,mention_rolesandmentionsfields are removed, as caching them is likely unnecessary, if you need these fields, please create an issue -
member,reactions,attachments,embedsandsticker_itemsfields are removed, since they are cached separately
Fields
activity_type: Option<MessageActivityType>activity_party_id: Option<String>application_cover_image: Option<ImageHash>application_description: Option<String>application_icon: Option<ImageHash>application_id: Option<Id<ApplicationMarker>>application_name: Option<String>interaction_application_id: Option<Id<ApplicationMarker>>channel_id: Id<ChannelMarker>content: Stringedited_timestamp: Option<Timestamp>flags: Option<MessageFlags>guild_id: Option<Id<GuildMarker>>id: Id<MessageMarker>kind: MessageTypemention_everyone: boolpinned: boolreference_channel_id: Option<Id<ChannelMarker>>reference_guild_id: Option<Id<GuildMarker>>reference_message_id: Option<Id<MessageMarker>>reference_fail_if_not_exists: Option<bool>referenced_message: Option<Id<MessageMarker>>timestamp: Timestampthread: Option<Id<ChannelMarker>>tts: boolwebhook_id: Option<Id<WebhookMarker>>Implementations
sourceimpl CachedMessage
impl CachedMessage
sourcepub fn update(&mut self, message: &MessageUpdate)
pub fn update(&mut self, message: &MessageUpdate)
Update the cached message with the message update