pub struct CachedMessageSticker {
    pub message_id: Id<MessageMarker>,
    pub format_type: StickerFormatType,
    pub id: Id<StickerMarker>,
    pub name: String,
}
A cached message sticker

It’s the same as twilight_model::channel::message::sticker::MessageSticker except:

  • message_id field is added, making it possible to return a message’s stickers

Fields

message_id: Id<MessageMarker>format_type: StickerFormatTypeid: Id<StickerMarker>name: String

Implementations

Create a cached message sticker from a given sticker and message ID