pub struct CachedPermissionOverwrite {
    pub channel_id: Id<ChannelMarker>,
    pub allow: Permissions,
    pub deny: Permissions,
    pub id: Id<GenericMarker>,
    pub kind: PermissionOverwriteType,
}
A cached permission overwrite

It’s the same as twilight_model::channel::permission_overwrite::PermissionOverwrite except:

  • channel_id field is added, making it possible to return a channel’s permission overwrites

Fields

channel_id: Id<ChannelMarker>allow: Permissionsdeny: Permissionsid: Id<GenericMarker>kind: PermissionOverwriteType

Implementations

Create a cached permission overwrite from a given permission overwrite and channel ID