Struct sparkle_cache::model::CachedPresence
source · pub struct CachedPresence {
pub guild_id: Id<GuildMarker>,
pub status: Status,
pub user: Id<UserMarker>,
}Expand description
A cached presence
It’s the same as twilight_model::gateway::presence::Presence except:
-
userfield is changed to a user ID, since users are cached separately -
client_statusfield is removed, as caching it is likely unnecessary, if you need this field, please create an issue -
activitiesfield is removed, since they’re cached separately
Fields
guild_id: Id<GuildMarker>status: Statususer: Id<UserMarker>Trait Implementations
sourceimpl Clone for CachedPresence
impl Clone for CachedPresence
sourcefn clone(&self) -> CachedPresence
fn clone(&self) -> CachedPresence
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for CachedPresence
impl Debug for CachedPresence
sourceimpl From<&Presence> for CachedPresence
impl From<&Presence> for CachedPresence
impl Copy for CachedPresence