Struct sparkle_cache::model::CachedReaction
source · [−]pub struct CachedReaction {
pub channel_id: Id<ChannelMarker>,
pub emoji: String,
pub guild_id: Option<Id<GuildMarker>>,
pub message_id: Id<MessageMarker>,
pub user_id: Id<UserMarker>,
}Expand description
A cached reaction
It’s the same as twilight_model::channel::Reaction except:
-
memberfield is removed, as members are cached separately -
emojifield is changed to a string that is either the ID or the name of the emoji
Fields
channel_id: Id<ChannelMarker>emoji: Stringguild_id: Option<Id<GuildMarker>>message_id: Id<MessageMarker>user_id: Id<UserMarker>Trait Implementations
sourceimpl Clone for CachedReaction
impl Clone for CachedReaction
sourcefn clone(&self) -> CachedReaction
fn clone(&self) -> CachedReaction
Returns a copy of the value. Read more
1.0.0 · sourceconst fn clone_from(&mut self, source: &Self)
const fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for CachedReaction
impl Debug for CachedReaction