pub struct CachedRole {
Show 15 fields pub guild_id: Id<GuildMarker>, pub user_id: Option<Id<UserMarker>>, pub color: u32, pub hoist: bool, pub icon: Option<ImageHash>, pub id: Id<RoleMarker>, pub managed: bool, pub mentionable: bool, pub name: String, pub permissions: Permissions, pub position: i64, pub tags_bot_id: Option<Id<UserMarker>>, pub tags_integration_id: Option<Id<IntegrationMarker>>, pub tags_premium_subscriber: Option<bool>, pub unicode_emoji: Option<String>,
}
A cached emoji

It’s the same as twilight_model::guild::Role except:

  • guild_id field is added, making it possible to return a guild’s roles

  • user_id field is added, making it possible to return a member’s roles

  • tags field is flattened, making this struct easier to cache

Fields

guild_id: Id<GuildMarker>user_id: Option<Id<UserMarker>>color: u32hoist: boolicon: Option<ImageHash>id: Id<RoleMarker>managed: boolmentionable: boolname: Stringpermissions: Permissionsposition: i64tags_bot_id: Option<Id<UserMarker>>tags_integration_id: Option<Id<IntegrationMarker>>tags_premium_subscriber: Option<bool>unicode_emoji: Option<String>

Implementations

Create a cached role from a given role and guild ID