The trait to define how to get and set data in the backend

This is for adding support for a backend

Traits

Provides methods to add or replace data in the cache
Implemented on backend errors, for example sqlx::Error