Struct sparkle_cache::model::CachedEmbedField
source · pub struct CachedEmbedField {
pub embed_id: Id<GenericMarker>,
pub inline: bool,
pub name: String,
pub value: String,
}Expand description
A cached embed field
It’s the same as [twilight_model::channel::embed::EmbedField] except:
embed_idfield is added, making it possible to return an embed’s fields
Fields
embed_id: Id<GenericMarker>inline: boolname: Stringvalue: StringImplementations
sourceimpl CachedEmbedField
impl CachedEmbedField
sourcepub fn from_embed_field(
embed_field: EmbedField,
embed_id: Id<GenericMarker>
) -> Self
pub fn from_embed_field(
embed_field: EmbedField,
embed_id: Id<GenericMarker>
) -> Self
Create a cached embed field from a given embed field and embed ID