Struct sparkle_cache::model::CachedRole
source · [−]pub struct CachedRole {Show 13 fields
pub guild_id: Id<GuildMarker>,
pub user_id: Option<Id<UserMarker>>,
pub color: u32,
pub hoist: bool,
pub icon: Option<ImageHash>,
pub id: Id<RoleMarker>,
pub managed: bool,
pub mentionable: bool,
pub name: String,
pub permissions: Permissions,
pub position: i64,
pub tags: Option<RoleTags>,
pub unicode_emoji: Option<String>,
}Expand description
A cached emoji
It’s the same as twilight_model::guild::Role except:
-
guild_idfield is added, making it possible to return a guild’s roles -
user_idfield is added, making it possible to return a member’s roles
Fields
guild_id: Id<GuildMarker>user_id: Option<Id<UserMarker>>color: u32hoist: boolicon: Option<ImageHash>id: Id<RoleMarker>managed: boolmentionable: boolname: Stringpermissions: Permissionsposition: i64unicode_emoji: Option<String>Implementations
sourceimpl CachedRole
impl CachedRole
sourcepub fn from_role(role: Role, guild_id: Id<GuildMarker>) -> Self
pub fn from_role(role: Role, guild_id: Id<GuildMarker>) -> Self
Create a cached role from a given role and guild ID