pub struct CachedSticker {
    pub message_id: Option<Id<MessageMarker>>,
    pub available: Option<bool>,
    pub description: Option<String>,
    pub format_type: StickerFormatType,
    pub guild_id: Option<Id<GuildMarker>>,
    pub id: Id<StickerMarker>,
    pub kind: Option<StickerType>,
    pub name: String,
    pub pack_id: Option<Id<StickerPackMarker>>,
    pub sort_value: Option<u64>,
    pub tags: Option<String>,
    pub user_id: Option<Id<UserMarker>>,
}
A cached sticker

It’s the same as twilight_model::channel::message::sticker::Sticker except:

  • message_id field is added, making it possible to return a message’s stickers

  • user field is changed to a user ID, since users are cached separately

  • available, kind and tags fields are made optional, as they’re not present in message stickers

Fields

message_id: Option<Id<MessageMarker>>available: Option<bool>description: Option<String>format_type: StickerFormatTypeguild_id: Option<Id<GuildMarker>>id: Id<StickerMarker>kind: Option<StickerType>name: Stringpack_id: Option<Id<StickerPackMarker>>sort_value: Option<u64>tags: Option<String>user_id: Option<Id<UserMarker>>

Implementations

Create a cached sticker from a given message sticker and message ID